@@ -15,7 +15,6 @@ def read_cache_json(cache_key):
     cache_json_path = os.path.join(home_path, '.aws', 'cli', 'cache', f'{cache_key}.json')
     with open(cache_json_path, 'r') as stream:
         cache_json = json.loads(stream.read())
-    # print(json.dumps(cache_json, indent=4, sort_keys=True))
     return cache_json
 
 
@@ -122,7 +121,7 @@ def call_sts_get_caller_identity(profile_name):
         logged_in_arn = sts_call_data['Arn']
         print(f'AWSHELPER: Generated cli cache. Logged in as {logged_in_arn}')
     except:
-        print(f'AWSHELPER: Unable to make aws call. You may have to run aws configure sso --profile {profile_name}')
+        print(f'AWSHELPER: Unable to make aws call. You may have to run "aws sso login --profile {profile_name}"')
         exit(1)
     return
 
@@ -141,17 +140,17 @@ def main():
     try:
         cache_data = read_cache_json(cache_key)
     except Exception:
-        print(f'AWSHELPER: Credentials file not found. Executing aws sts get-caller-identity --profile {profile_name} to generate it')
+        print(f'AWSHELPER: Credentials file not found. Executing "aws sts get-caller-identity --profile {profile_name}" to generate it')
         call_sts_get_caller_identity(profile_name)
 
     if not cache_data:
         try:
             cache_data = read_cache_json(cache_key)
         except Exception:
-            sys.exit(f'AWSHELPER: Unable to read cache file generated by aws cli. You might not be logged in (run aws configure sso --profile {profile_name}')
+            sys.exit(f'AWSHELPER: Unable to read cache file generated by aws cli. You might not be logged in (run "aws sso login --profile {profile_name}" to log in, or "aws configure sso --profile {profile_name}" for first-time setup')
 
     if check_cache_expiry(cache_data['Credentials']['Expiration']):
-        print(f'AWSHELPER: Credentials cache has expired. Executing Executing aws sts get-caller-identity --profile {profile_name} to attempt to refresh it')
+        print(f'AWSHELPER: Credentials cache has expired. Executing "aws sts get-caller-identity --profile {profile_name}" to attempt to refresh it')
         call_sts_get_caller_identity(profile_name)
         cache_data = read_cache_json(cache_key)
 
@@ -162,6 +161,9 @@ def main():
         'AWS_ACCESS_KEY_ID': cache_data['Credentials']['AccessKeyId'],
         'AWS_SECRET_ACCESS_KEY': cache_data['Credentials']['SecretAccessKey'],
         'AWS_SESSION_TOKEN': cache_data['Credentials']['SessionToken'],
+        'AWSHELPER_ENABLED': 'YES',
+        'AWSHELPER_PROFILE': profile_name
+
     }
 
     exec_env_vars = os.environ.copy()
